@@ -23,13 +23,14 @@ pie3D.labels<-function(radialpos,radius=1,height=0.1,theta=pi/6,
 }
 
 draw.tilted.sector<-function(x=0,y=0,edges=NA,radius=1,height=0.1,
- theta=pi/6,start=0,end=pi*2,border=par("fg"),col=par("bg"),explode=0,
- shade=0.8) {
+ theta=pi/6,start=0,end=pi*2,border=par("fg"),col=par("bg"),
+ explode=0,shade=0.8) {
 
  if(is.na(edges)) edges<-trunc(20*(end-start))
  angleinc<-(end-start)/edges
  angles<-c(seq(start,end,by=angleinc),end)
  viscurve<-(angles>=pi)&(angles<=2*pi)
+ viscurvew<-(angles>=3*pi)
  nv<-length(angles)
  bisector<-(start+end)/2
  if(explode){
@@ -57,11 +58,13 @@ draw.tilted.sector<-function(x=0,y=0,edges=NA,radius=1,height=0.1,
   # display the 'outside' of the sector
   polygon(c(xp[viscurve],rev(xp[viscurve])),c(yp[viscurve]-height,
    rev(yp[viscurve])+height),border=border,col=shadecol)
+  # and any "wraparound" values
+  polygon(c(xp[viscurvew],rev(xp[viscurvew])),c(yp[viscurvew]-height,
+   rev(yp[viscurvew])+height),border=border,col=shadecol)
   if(explode > 0)
    # display the 'left' (front) side
    polygon(c(xp[1],x,x,xp[1],xp[1]),c(yp[1]-height,y-height,
-    y+height,yp[1]+height,yp[1]),border=border,
-    col=shadecol)
+    y+height,yp[1]+height,yp[1]),border=border,col=shadecol)
  }
  else {
   if(start > pi/2) {
@@ -75,8 +78,7 @@ draw.tilted.sector<-function(x=0,y=0,edges=NA,radius=1,height=0.1,
    }
    if(end > pi)
     polygon(c(xp[viscurve],rev(xp[viscurve])),c(yp[viscurve]-height,
-     rev(yp[viscurve])+height),border=border,
-     col=shadecol)
+     rev(yp[viscurve])+height),border=border,col=shadecol)
   }
   else {
    if(end > pi || start<2*pi)
@@ -101,17 +103,18 @@ draw.tilted.sector<-function(x=0,y=0,edges=NA,radius=1,height=0.1,
 
 pie3D<-function(x,edges=NA,radius=1,height=0.1,theta=pi/6, 
  start=0,border=par("fg"),col=NULL,labels=NULL,labelpos=NULL,
- labelcol=par("fg"),labelcex=1.5,sector.order=NULL,explode=0,
- shade=0.8,mar=c(4,4,4,4),pty="s",...) {
+ labelcol=par("fg"),labelcex=1.5,labelrad=1.25,sector.order=NULL,
+ explode=0,shade=0.8,mar=c(4,4,4,4),pty="s",...) {
 
+ if(any(is.na(x))) x<-x[!is.na(x)]
  if(is.null(labels)) labels<-names(x)
  if(!is.numeric(x) || any(x < 0)) 
   stop("pie3D: x values must be positive numbers")
  # drop NAs
- if(any(is.na(x))) x<-x[!is.na(x)]
  oldmar<-par("mar")
  par(pty=pty,mar=mar,xpd=TRUE)
  x<-c(cumsum(c(0,x))/sum(x))*2*pi+start
+ labelrad<-labelrad+explode
  lenx<-length(x)
  # add the last edge
  x[lenx]<-2*pi+start
@@ -124,7 +127,8 @@ pie3D<-function(x,edges=NA,radius=1,height=0.1,theta=pi/6,
    order(sin((x[2:lenx]+x[1:(lenx-1)])/2),decreasing=TRUE)
  bc<-rep(0,nsectors)
  # set up an empty plot
- plot(0,xlab="",ylab="",xlim=c(-1,1),ylim=c(-1,1),type="n",axes=FALSE,...)
+ plot(0,xlab="",ylab="",xlim=c(-1,1),ylim=c(-1,1),type="n",
+  axes=FALSE,...)
  for(i in sector.order) {
   if(x[i] != x[i+1])
    bc[i]<-draw.tilted.sector(radius=radius,height=height, 
@@ -135,7 +139,8 @@ pie3D<-function(x,edges=NA,radius=1,height=0.1,theta=pi/6,
  if(!is.null(labels)) {
   if(!is.null(labelpos)) bc<-labelpos
   pie3D.labels(bc,radius=radius,height=height,theta=theta, 
-    labels=labels,labelcol=labelcol,labelcex=labelcex)
+   labels=labels,labelcol=labelcol,labelcex=labelcex,
+   labelrad=labelrad)
  }
  par(mar=oldmar,xpd=FALSE,pty="m")
  invisible(bc)
